<?php
/**
 * @file
 * This file will be processed if time is set
 */
/**
 * Implementation of hook_theme_registry_alter().
 *
 * Make drupal to use maintenance-countdown-page.tpl.php in
 * maintenance mode if timer is set
 *
 * @param $theme_registry The entire cache of theme registry information, post-processing.
 */
function mcd_theme_registry_alter(&$theme_registry) {
  $path = drupal_get_path('module', 'mcd');

  $theme = variable_get('theme_default', 'garland');
  $theme_path = drupal_get_path('theme', $theme);

  $theme_registry['maintenance_page']['template'] = 'maintenance-countdown-page';
  $theme_registry['maintenance_page']['path'] = $path;
  $theme_registry['maintenance_page']['type'] = 'module';
}

/**
 * Generate the jQuery output
 */
function mcd_js_countdown() {
//  get stoptime like 1315776380
  $stoptime = variable_get('mcd_stoptime', NULL);
  $output = "jQuery(document).ready(function() {\$('#countdown_dashboard').countDown({targetDate: {";
  $output .= "'day': " . date('j', $stoptime) . ",";
  $output .= "'month': " . date('n', $stoptime) . ",";
  $output .= "'year': " . date('Y', $stoptime) . ",";
  $output .= "'hour': " . date('G', $stoptime) . ",";
  $output .= "'min': " . date('i', $stoptime) . ",";
  $output .= "'sec': " . date('s', $stoptime) . ",";
  $output .= "'utc': '" . date('O', $stoptime) . "'";
  $output .= "}";
  
  if (variable_get('mcd_time_up_message', NULL) || variable_get('mcd_reload_button', 0) != 1) {
    $output .= ", onComplete: function() {";
//  slide down 'time is up' message or 'Reload' button
    if (variable_get('mcd_time_up_message', NULL) || variable_get('mcd_reload_button', 0) == 0) {
      $output .= " \$('#complete_message').slideDown();";
    }
    if (variable_get('mcd_reload_button', 0) == 2) {
      $output .= " setTimeout(function() {location.reload();}, 15000)";
    }
    $output .= "}";
  }
// close countDown
  $output .= "});";
//  reload current page by clicking 'Reload' button
  if (variable_get('mcd_reload_button', 0) == 0) {
    $output .= " \$('#page_reload').click(function() {location.reload()});";
  }
  $output .= "";
// close function
  $output .= "});";
  return $output;
}

/**
 * Add some variables for maintenance-coundown-page.tpl.php file.
 *
 * To add or override something you can use the same
 * TEMPLATE_preprocess_maintenance_page function  in your theme
 * template.php file.
 *
 * @param $variables
 */
function mcd_preprocess_maintenance_page(&$variables) {
  $path = drupal_get_path('module', 'mcd');
//  unset regions
  unset($variables['left']);
  unset($variables['right']);
//  add theme css
  $variables['styles'] = drupal_add_css($path . '/styles/' . variable_get('mcd_page_themes', 'light') . '.css', 'theme', 'all');
    $css = drupal_add_css();
    unset($css['all']['module']); // we don't need all these css
  $variables['styles'] = drupal_get_css($css);
//  we need jquery 1.4.1+ to make it work
  $variables['scripts'] = drupal_add_js($path . '/js/jquery-1.4.1.min.js', 'module', 'header');
  $variables['scripts'] = drupal_add_js($path . '/js/jquery.lwtCountdown-1.0-min.js', 'module', 'header');
  $variables['scripts'] = drupal_add_js(mcd_js_countdown(), 'inline');
//  we don't need core js for this page
    $js = drupal_add_js(NULL, NULL, 'header');
    unset($js['core']);
  $variables['scripts'] = drupal_get_js('header', $js);
  $variables['time_up_message'] = variable_get('mcd_time_up_message', NULL);
  if (variable_get('mcd_reload_button', 0) == 0) {
    $variables['reload_button'] = l(t('♻ Reload'), $_GET['q'] , array('attributes' => array('id' => 'page_reload', 'title' => t('Reload this page'))));
  };
}
